
// 文件大小转换成kb/mb/gb
function bytesToSize(bytes) {
    if (bytes == "" || bytes <= 0) {
        return '0 B';
    }
    if (bytes === 0) return '0 B';
    var k = 1024, // or 1000
    sizes = ['B', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
    i = Math.floor(Math.log(bytes) / Math.log(k));
    var returnstr = "";
    if (i < 3) {
        returnstr = (bytes / Math.pow(k, i)).toFixed(0) + ' ' + sizes[i];
    } else {
        returnstr = (bytes / Math.pow(k, i)).toFixed(2) + ' ' + sizes[i];
    }
    return returnstr;
}

/// <summary>
/// 检测服务端项目组磁盘空间状态
/// </summary>
/// <param name="pi_id">项目组ID</param>
/// <param name="addSize">要增加的大小单位KB</param>
/// <returns>
/// -1：网络异常;
/// 0 ：不可用;
/// 1：可用;
/// </returns>
function util_checkPISpace(pi_id,addSize){
	try
    {
		var para = new HashMap();
		para.put("pi_id",pi_id);
		// 查询当前空间和使用情况
		var result = doCallAjax.doSynchronousAjax("ProjectItemModel", "getSizeAndCount", para);
        var currStatus = JSON.parse(result).status;
        // 查询当前使用空间，查询失败按已满处理
        if (currStatus!="200"|| currStatus=="301")
        {
            return -1;
        }
        
        // 查询项目组最大空间
        var maxResult = doCallAjax.doSynchronousAjax("UserPayModel", "queryProjItemProd", para);
        var maxStatus = JSON.parse(maxResult).status;
        // 查询项目组最大空间，查询失败按已满处理
        if (maxStatus!="200"|| maxStatus=="301")
        {
            return -1;
        }
        var fileSum = JSON.parse(result).fileSum;    //获取空间概况，以字节为单位
        var user_space = JSON.parse(maxResult).user_space=="" ? "0" : JSON.parse(maxResult).user_space;    //获取项目组最大空间
        var maxSize = parseInt(user_space) * 1024 * 1024 * 1024;
        var sumSize = addSize + parseInt(fileSum);
        if (sumSize > maxSize)
        {
            return 0;
        }
        return 1;
    }catch (e){
    	console.log("Error_[module.pimember.js]_[util_checkPISpace]:"+e);
        return 0;
    }
}

// 获取文件样式
var DocType = ["doc", "docx", "rtf"];
var ExcelType = ["xls", "xlsx", "excel"];
var PPtType = ["ppt", "pptx", "pps", "ppsx", "ppsm"];
var TxtType = ["txt"];
var ZipType = ["zip", "rar"];
var ImageType = ["jpg", "jpeg", "gif", "bmp", "png"];
var VideoType = ["wmv", "avi", "dat", "asf", "rm", "rmvb", "mpg", "mpeg", "mkv", "dvix", "dv", "flv", "mov", "mp4", "qt", "smil", "swf", "wmv", "3gp"];
var Mp3Type = ["mp3", "wav", "wma", "mid"];
var PdfType = ["pdf"];
function getTypeCss(doctype) {
    if (doctype == "" || doctype == null || doctype == undefined) {
        doctype = "icon_file";
        return doctype;
    }
    doctype = doctype.toLowerCase();
    if (DocType.join(",").indexOf(doctype) >= 0) {
        return "icon_word";
    }
    if (ExcelType.join(",").indexOf(doctype) >= 0) {
        return "icon_excel";
    }
    if (PPtType.join(",").indexOf(doctype) >= 0) {
        return "icon_ppt";
    }
    if (TxtType.join(",").indexOf(doctype) >= 0) {
        return "icon_txt";
    }
    if (ZipType.join(",").indexOf(doctype) >= 0) {
        return "icon_rar";
    }
    if (ImageType.join(",").indexOf(doctype) >= 0) {
        return "icon_image";
    }
    if (VideoType.join(",").indexOf(doctype) >= 0) {
        return "icon_video";
    }
    if (Mp3Type.join(",").indexOf(doctype) >= 0) {
        return "icon_music";
    }
    if (PdfType.join(",").indexOf(doctype) >= 0) {
        return "icon_pdf";
    }
    return "icon_other";
}

function checkCanPreviewFile(doc_type){
	var canPreviewFiles = ["doc", "docx", "ppt", "pptx", "xls", "xlsx", "pdf", "tif","txt"];
	doc_type = doc_type.toLowerCase();
	if (canPreviewFiles.join(",").indexOf(doc_type) >= 0) {
        return true;
    }
	return false;
}
/*
 * 检测是否可以转pdf
 */
function checkToPdf(doc_type){
	var convertPdfFiles = ["tif","txt"];
	doc_type = doc_type.toLowerCase();
	if (convertPdfFiles.join(",").indexOf(doc_type) >= 0) {
        return true;
    }
	return false;
}
/*
 * 检测是否是图片
 */
function checkJpgType(doc_type){
	var jpgTypeFiles = ["jpg","jpeg","png","bmp","gif"];
	doc_type = doc_type.toLowerCase();
	if (jpgTypeFiles.join(",").indexOf(doc_type) >= 0) {
        return true;
    }
	return false;
}

/**去掉空格**/
/** 将数据库中存储的" "替换为页面中html代码&nbsp;**/
function replaceSpace(fileName) {
    var replaceStr = " ";
    fileName = (fileName.split(replaceStr).join('&nbsp;'));
    return fileName;
}

//验证特殊字符
function checkStr(str) {
    var vkeyWords = "<>@/'\"#$%&^*\\/?![]{}|:";
    var tmpstr = "";
    for (var i = 0; i < vkeyWords.length; i++) {
        tmpstr = vkeyWords.substring(i, i + 1);
        if (str.indexOf(tmpstr) != -1) {
            return true;
        }
    }
    return false;
}

//验证是否含有反斜杠
function CheckSlash(str) {
    var vkeyWords = "\\";
    var tmpstr = "";
    for (var i = 0; i < vkeyWords.length; i++) {
        tmpstr = vkeyWords.substring(i, i + 1);
        if (str.indexOf(tmpstr) != -1) {
            return true;
        }
    }
    return false;
}

/***************************************************************日期转换相关************************************************************************************/

//扩展Date的format方法
Date.prototype.format = function (format) {
    var o = {
        "M+": this.getMonth() + 1,
        "d+": this.getDate(),
        "h+": this.getHours(),
        "m+": this.getMinutes(),
        "s+": this.getSeconds(),
        "q+": Math.floor((this.getMonth() + 3) / 3),
        "S": this.getMilliseconds()
    }
    if (/(y+)/.test(format)) {
        format = format.replace(RegExp.$1, (this.getFullYear() + "").substr(4 - RegExp.$1.length));
    }
    for (var k in o) {
        if (new RegExp("(" + k + ")").test(format)) {
            format = format.replace(RegExp.$1, RegExp.$1.length == 1 ? o[k] : ("00" + o[k]).substr(("" + o[k]).length));
        }
    }
    return format;
}

/**
*转换日期对象为日期字符串
* @param date 日期对象
* @param isFull 是否为完整的日期数据,
* 为true时, 格式如"2000-03-05 01:05:04"
* 为false时, 格式如 "2000-03-05"
* @return 符合要求的日期字符串
*/
function getSmpFormatDate(date, isFull) {
    var pattern = "";
    if (isFull == true || isFull == undefined) {
        pattern = "yyyy/MM/dd hh:mm:ss";
    } else {
        pattern = "yyyy-MM-dd";
    }
    
    return getFormatDate(date, pattern);
}

/**
*转换当前日期对象为日期字符串
* @param date 日期对象
* @param isFull 是否为完整的日期数据,
* 为true时, 格式如"2000-03-05 01:05:04"
* 为false时, 格式如 "2000-03-05"
* @return 符合要求的日期字符串
*/
function getSmpFormatNowDate(isFull) {
    return getSmpFormatDate(new Date(), isFull);
}

/**
*转换long值为日期字符串
* @param l long值
* @param isFull 是否为完整的日期数据,
* 为true时, 格式如"2000-03-05 01:05:04"
* 为false时, 格式如 "2000-03-05"
* @return 符合要求的日期字符串
*/
function getSmpFormatDateByLong(l, isFull) {
	var teml = l+""; 
	if(teml.indexOf(":")>0){
		teml = teml.replace("-","/").replace("-","/");
		return teml;
	}else{
		teml= parseInt(teml);
	}
    return getSmpFormatDate(new Date(teml), isFull);
}

/**
*转换long值为日期字符串
* @param l long值
* @param pattern 格式字符串,例如：yyyy-MM-dd hh:mm:ss
* @return 符合要求的日期字符串
*/
function getFormatDateByLong(l, pattern) {
    return getFormatDate(new Date(l), pattern);
}

/**
*转换日期对象为日期字符串
* @param l long值
* @param pattern 格式字符串,例如：yyyy-MM-dd hh:mm:ss
* @return 符合要求的日期字符串
*/
function getFormatDate(date, pattern) {
    if (date == undefined) {
        date = new Date();
    }
    if (pattern == undefined) {
        pattern = "yyyy/MM/dd hh:mm:ss";
    }
    return date.format(pattern);
} 

// 计算天数差的函数，通用  
function dateDiff(sDate1, sDate2) {    //sDate1和sDate2是2006-12-18格式  
    var iDays;
//    aDate = sDate1.split("-");
//    oDate1 = new Date(aDate[1] + '-' + aDate[2] + '-' + aDate[0]); //转换为12-18-2006格式  
//    aDate = sDate2.split("-");
//    oDate2 = new Date(aDate[1] + '-' + aDate[2] + '-' + aDate[0]);
    var startTime = new Date(Date.parse(sDate1.replace(/-/g,   "/"))).getTime();   //将日期转换为Data格式再转换为毫秒数  
    var endTime = new Date(Date.parse(sDate2.replace(/-/g,   "/"))).getTime();     
    if (Date.parse(sDate2)<Date.parse(sDate1)) {
        iDays = 0;
    } else {
//    	debugger;
//        iDays = parseInt(Math.abs(endTime - startTime) / 1000 / 60 / 60 / 24); //把相差的毫秒数转换为天数
        iDays = Math.floor((endTime - startTime)/(24*60*60*1000)); //把相差的毫秒数转换为天数
    }
    return iDays;
}

/*************************************************************日期转换相关结束**************************************************************************************/

/**
*转换权限字符串 
*@'abc':'a','cde':'1'@
*{"abc":"a","cde","1"}
* @param l long值
* @param pattern 格式字符串,例如：yyyy-MM-dd hh:mm:ss
* @return 符合要求的日期字符串
*/
function parsePerms(perms)
{
    if (perms == null || perms.Length == 0)
    {
        return "";
    }
    perms = perms.replace("@", "{");
    perms = perms.replace("@", "}");
    perms = perms.replace(/\'/g, "\"");
    return perms;
}

//判断权限
function hasPermission(str, perms) {
    var PermObj = parsePerms(str);
    PermObj=JSON.parse(PermObj);
    if (perms == "piinfo") {   //项目组信息管理
        return parseBool(PermObj.piinfo);
    }
    if (perms == "pimember") {  //项目组成员管理
        return parseBool(PermObj.pimember);
    }
    if (perms == "pirolemanage") {  //项目组角色管理
        return parseBool(PermObj.pirolemanage);
    }
    if (perms == "piaddpr") {   //创建项目
        return parseBool(PermObj.piaddpr);
    }

    if (perms == "prupdatepr") {   //项目信息管理
        return parseBool(PermObj.prupdatepr);
    }
    if (perms == "prmember") {   //项目成员管理
        return parseBool(PermObj.prmember);
    }
    if (perms == "prrolemanage") {   //项目角色管理
        return parseBool(PermObj.prrolemanage);
    }
    if (perms == "prdel") {    //删除项目
        return parseBool(PermObj.prdel);
    }
    if (perms == "prrecycled") {     //项目回收站
        return parseBool(PermObj.prrecycled);
    }
    if (perms == "prfoview") {   //查看者
        return parseBool(PermObj.prfoview);
    }
    if (perms == "prfomanage") {   //编辑者
        return parseBool(PermObj.prfomanage);
    }

    return false;
}
//判断文件权限
function hasFilePermission(str, perms) {
    var PermObj = parsePerms(str);
    PermObj=JSON.parse(PermObj);
    if (perms == "modify") {   //编辑权限
        return parseBool(PermObj.modify);
    }
    
    if (perms == "preview") {  //预览权限
        return parseBool(PermObj.preview);
    }
    
    if (perms == "createdoc") {  //新建权限
        return parseBool(PermObj.createdoc);
    }
    
    if (perms == "uploaddoc") {   //上传权限
        return parseBool(PermObj.uploaddoc);
    }
    
    if (perms == "download") {  //下载权限
        return parseBool(PermObj.download);
    }
    
    if (perms == "copy") {   //复制权限
        return parseBool(PermObj.copy);
    }

    if (perms == "remove") {   //移动
        return parseBool(PermObj.remove);
    }
    
    if (perms == "delete") {   //删除权限
        return parseBool(PermObj["delete"]);
    }
    
    if (perms == "furl") {   //外链权限
        return parseBool(PermObj.furl);
    }
    
    if (perms == "rollback") {    //还原版本
        return parseBool(PermObj.rollback);
    }
    
    return false;
}
// 转换成bool
function parseBool(str) {
    if (str == "true") {
        return true;
    }
    return false;
}
//生成随机数
function randomString(len){
	var $chars = 'ABCDEFGHJKMNPQRSTWXYZabcdefhijkmnprstwxyz2345678';    /****默认去掉了容易混淆的字符oOLl,9gq,Vv,Uu,I1****/
	var maxPos = $chars.length;
	var pwd = '';
	for ( var i = 0; i < len; i++) {
		pwd += $chars.charAt(Math.floor(Math.random() * maxPos));
	}
	return pwd;
}

function stringFormat() {
    if (arguments.length == 0)
        return null;
    var str = arguments[0];
    for (var i = 1; i < arguments.length; i++) {
        var re = new RegExp('\\{' + (i - 1) + '\\}', 'gm');
        str = str.replace(re, arguments[i]);
    }
    return str;
}

var base64EncodeChars = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
var base64DecodeChars = new Array(
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, 62, -1, -1, -1, 63,
    52, 53, 54, 55, 56, 57, 58, 59, 60, 61, -1, -1, -1, -1, -1, -1,
    -1,  0,  1,  2,  3,  4,  5,  6,  7,  8,  9, 10, 11, 12, 13, 14,
    15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, -1, -1, -1, -1, -1,
    -1, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40,
    41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, -1, -1, -1, -1, -1);
//base64加密
function base64encode(str) {
    var out, i, len;
    var c1, c2, c3;

    len = str.length;
    i = 0;
    out = "";
    while(i < len) {
    c1 = str.charCodeAt(i++) & 0xff;
    if(i == len)
    {
        out += base64EncodeChars.charAt(c1 >> 2);
        out += base64EncodeChars.charAt((c1 & 0x3) << 4);
        out += "==";
        break;
    }
    c2 = str.charCodeAt(i++);
    if(i == len)
    {
        out += base64EncodeChars.charAt(c1 >> 2);
        out += base64EncodeChars.charAt(((c1 & 0x3)<< 4) | ((c2 & 0xF0) >> 4));
        out += base64EncodeChars.charAt((c2 & 0xF) << 2);
        out += "=";
        break;
    }
    c3 = str.charCodeAt(i++);
    out += base64EncodeChars.charAt(c1 >> 2);
    out += base64EncodeChars.charAt(((c1 & 0x3)<< 4) | ((c2 & 0xF0) >> 4));
    out += base64EncodeChars.charAt(((c2 & 0xF) << 2) | ((c3 & 0xC0) >>6));
    out += base64EncodeChars.charAt(c3 & 0x3F);
    }
    return out;
}
//base64解码
function base64decode(str) {
    var c1, c2, c3, c4;
    var i, len, out;

    len = str.length;
    i = 0;
    out = "";
    while(i < len) {
    /* c1 */
    do {
        c1 = base64DecodeChars[str.charCodeAt(i++) & 0xff];
    } while(i < len && c1 == -1);
    if(c1 == -1)
        break;

    /* c2 */
    do {
        c2 = base64DecodeChars[str.charCodeAt(i++) & 0xff];
    } while(i < len && c2 == -1);
    if(c2 == -1)
        break;

    out += String.fromCharCode((c1 << 2) | ((c2 & 0x30) >> 4));

    /* c3 */
    do {
        c3 = str.charCodeAt(i++) & 0xff;
        if(c3 == 61)
        return out;
        c3 = base64DecodeChars[c3];
    } while(i < len && c3 == -1);
    if(c3 == -1)
        break;

    out += String.fromCharCode(((c2 & 0XF) << 4) | ((c3 & 0x3C) >> 2));

    /* c4 */
    do {
        c4 = str.charCodeAt(i++) & 0xff;
        if(c4 == 61)
        return out;
        c4 = base64DecodeChars[c4];
    } while(i < len && c4 == -1);
    if(c4 == -1)
        break;
    out += String.fromCharCode(((c3 & 0x03) << 6) | c4);
    }
    return out;
}

function openJiff(){
	
}
/**
 * 计算百分比
 * @param number1 当前数
 * @param number2 总数
 * @returns 返回百分比
 */
function percentage(number1, number2) {
    return (Math.round(number1 / number2 * 10000) / 100.00 + "%");// 小数点后两位百分比
}

/**
 * 获取label标签的html代码
 * @author SuHao
 * @param labelInfos
 * @returns 返回label标签的html代码
 */
function getlabelHtml(labelInfos){
	var labelHtmls = [];
	if(labelInfos!=null && labelInfos!="" && labelInfos!=undefined){
		$.each(labelInfos, function (index, labelInfo) {
			switch(index)
			{
				case 0:
					labelHtmls.push("<em class=\"pola\">"+labelInfo.label_name+"</em>");
				  break;
				case 1:
					labelHtmls.push("<em class=\"polb\">"+labelInfo.label_name+"</em>");
				  break;
				case 2:
					labelHtmls.push("<em class=\"polc\">"+labelInfo.label_name+"</em>");
				  break;
				case 3:
					labelHtmls.push("<em class=\"paints\">"+labelInfo.label_name+"</em>");
				  break;
				case 4:
					labelHtmls.push("<em class=\"pola\">"+labelInfo.label_name+"</em>");
				  break;
				case 5:
					labelHtmls.push("<em class=\"polb\">"+labelInfo.label_name+"</em>");
				  break;
				case 6:
					labelHtmls.push("<em class=\"polc\">"+labelInfo.label_name+"</em>");
				  break;
				case 7:
					labelHtmls.push("<em class=\"paints\">"+labelInfo.label_name+"</em>");
				  break;
			};
		 });
	}
	return labelHtmls.join("");
}

/**
 * 模拟post请求
 * url跳转地址
 * map参数（HashMap()）
 * target打开方式
 **/
function postSubmit(url,map,target){
	//1、创建form对象
	var tempform = document.createElement("form");
	tempform.action = url;
	tempform.method = "post";
	tempform.style.display = "none";
	
	/**
	* 设置打开页面的方式
	*/
	switch(target.toLowerCase()){
       case "_blank":
           tempform.target = "_blank";
           break;
       case "_self":
           tempform.target = "_self";
           break;
       default:tempform.target = "_self";
    }
    
    /**
    *  设置参数
    */
	var keys = map.keys();
	for(var x in keys){
	    var opt = document.createElement("input");
	    opt.name = keys[x];
	    opt.value = map.get(keys[x]);
	    tempform.appendChild(opt);
	}
	
	/**
	*  提交
	*/
	var opt = document.createElement("input");
	opt.type = "submit";
	tempform.appendChild(opt)
	document.body.appendChild(tempform);
	tempform.submit();
	document.body.removeChild(tempform);
}